@@ -56,7 +56,7 @@ class FacebookScraper:
         try:
             kwargs['verify'] = False
             if os.getenv('SOCIAL_METRIC_HTTP_PROXY') is not None:
-                kwargs['proxy'] = {
+                kwargs['proxies'] = {
                     'http': os.getenv('SOCIAL_METRIC_HTTP_PROXY'),
                     'https': os.getenv('SOCIAL_METRIC_HTTPS_PROXY')
                 }
